@@ -32,9 +32,6 @@ class compiz(samba):
     sepFields = "\n"
     reSepFields = re.compile(sepFields)
 
-    def __init__(self, text):
-        samba.__init__(self, text)
-
     def join(self, compizObj):
         """Объединяем конфигурации"""
         if isinstance(compizObj, compiz):
