@@ -188,3 +188,24 @@ class VariableOsX11VideoDrv(ReadonlyVariable):
             if drv in list_video:
                 return drv
         return "default"
+
+
+class VariableClResolutions(Variable):
+    """
+    Список поддерживаемых разрешений для фоновых изображений по умолчанию
+    """
+    type = "list"
+    value = ["640x480", "800x480", "800x600", "1024x576", "1024x600",
+             "1024x768", "1200x800", "1280x800", "1280x720",
+             "1280x768", "1280x1024", "1360x768", "1366x768",
+             "1368x768", "1400x1050", "1440x900", "1680x945",
+             "1680x1050", "1920x1080", "1920x1200", "1600x768",
+             "1600x900", "1600x1200", "2048x1152", "2560x1440",
+             "2560x1600"]
+
+class VariableClImageFormats(Variable):
+    """
+    Список поддерживаемых форматов изображений для фона
+    """
+    type = "list"
+    value = ["jpg", "png"]
